```{include} ../README.md
:start-line: 0
:end-line: 3
```

- Get started with [Quickstart](tutorials/quickstart).
- Check out the [API](api).
- Learn about design decisions and comparisons to other tools: [notes](notes/index).

```{toctree}
:maxdepth: 1
:hidden:

tutorials/index
api
guides/index
notes/index
examples/index
changelog
```
